Cc: Namhyung Kim <namhy...@kernel.org>
Cc: Jiri Olsa <jo...@redhat.com>
Signed-off-by: Taeung Song <treeze.tae...@gmail.com>
---
 tools/perf/ui/browsers/annotate.c | 14 +++++++++++---
 1 file changed, 11 insertions(+), 3 deletions(-)

diff --git a/tools/perf/ui/browsers/annotate.c 
b/tools/perf/ui/browsers/annotate.c
index 80f38da..faca1b9 100644
--- a/tools/perf/ui/browsers/annotate.c
+++ b/tools/perf/ui/browsers/annotate.c
@@ -42,6 +42,7 @@ static struct annotate_browser_opt {
             jump_arrows,
             show_linenr,
             show_nr_jumps,
+            show_nr_samples,
             show_total_period;
 } annotate_browser__opts = {
        .use_offset     = true,
@@ -155,6 +156,9 @@ static void annotate_browser__write(struct ui_browser 
*browser, void *entry, int
                        if (annotate_browser__opts.show_total_period) {
                                ui_browser__printf(browser, "%11" PRIu64 " ",
                                                   bdl->samples[i].he.period);
+                       } else if (annotate_browser__opts.show_nr_samples) {
+                               ui_browser__printf(browser, "%6" PRIu64 " ",
+                                                  
bdl->samples[i].he.nr_samples);
                        } else {
                                ui_browser__printf(browser, "%6.2f ",
                                                   bdl->samples[i].percent);
@@ -167,7 +171,8 @@ static void annotate_browser__write(struct ui_browser 
*browser, void *entry, int
                        ui_browser__write_nstring(browser, " ", pcnt_width);
                else {
                        ui_browser__printf(browser, "%*s", pcnt_width,
-                                          
annotate_browser__opts.show_total_period ? "Period" : "Percent");
+                                          
annotate_browser__opts.show_total_period ? "Period" :
+                                          
annotate_browser__opts.show_nr_samples ? "Samples" : "Percent");
                }
        }
        if (ab->have_cycles) {
@@ -931,9 +936,11 @@ static int annotate_browser__run(struct annotate_browser 
*browser,
 int map_symbol__tui_annotate(struct map_symbol *ms, struct perf_evsel *evsel,
                             struct hist_browser_timer *hbt)
 {
        /* Set default value for show_total_period.  */
        annotate_browser__opts.show_total_period =
-         symbol_conf.show_total_period;
+               symbol_conf.show_total_period;
+       annotate_browser__opts.show_nr_samples =
+               symbol_conf.show_nr_samples;
 
        return symbol__tui_annotate(ms->sym, ms->map, evsel, hbt);
 }
@@ -1184,6 +1191,7 @@ static struct annotate_config {
        ANNOTATE_CFG(jump_arrows),
        ANNOTATE_CFG(show_linenr),
        ANNOTATE_CFG(show_nr_jumps),
+       ANNOTATE_CFG(show_nr_samples),
        ANNOTATE_CFG(show_total_period),
        ANNOTATE_CFG(use_offset),
 };
@@ -931,9 +936,11 @@ static int annotate_browser__run(struct annotate_browser 
                             struct hist_browser_timer *hbt)
 {
-       /* Set default value for show_total_period.  */
+       /* Set default value for show_total_period and show_nr_samples  */
        annotate_browser__opts.show_total_period =
-- 
2.7.4

Reply via email to